var indexSectionsWithContent =
{
  0: "012347:_abcdefghiklmnopqrstuvwxyz~",
  1: "_abcdefghiklmnopqrstuvwxz",
  2: "oprs",
  3: "abceghimnoprstuvwx",
  4: "_abcdefghiklmnopqrstuvwxyz~",
  5: "_abcdefghiklmnopqrstuvwxyz",
  6: "_abcdefghiklmnoprstuvwxz",
  7: "abcdefghilmopqrstuvwx",
  8: "abcdefghiklmnopqrstuvwxyz",
  9: "dlnps",
  10: "alo",
  11: "_acdefgimnoprstuvw",
  12: "acdegilmoprs",
  13: "023abcdfghilmnoprstuvwyz"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "properties",
  10: "related",
  11: "defines",
  12: "groups",
  13: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Properties",
  10: "Friends",
  11: "Macros",
  12: "Modules",
  13: "Pages"
};

